@@ -423,7 +423,15 @@ class BackupEngine {
     }
     
     private function triggerBackgroundProcessing() {
-        // Use a lock file to prevent multiple worker instances
+        // Trigger backup creation worker
+        $this->triggerBackupWorker();
+
+        // Trigger upload worker (separate process)
+        $this->triggerUploadWorker();
+    }
+
+    private function triggerBackupWorker() {
+        // Use a lock file to prevent multiple backup worker instances
         $lockFile = '/tmp/backup-worker.lock';
 
         // Check if a worker is already running
@@ -439,13 +447,38 @@ class BackupEngine {
             }
         }
 
-        // Trigger background processing asynchronously
+        // Trigger backup creation worker asynchronously
         $scriptPath = dirname(__DIR__) . '/scripts/backup-worker.php';
         if (file_exists($scriptPath)) {
             // Run in background without blocking the response
             exec("php " . escapeshellarg($scriptPath) . " > /dev/null 2>&1 &");
         }
     }
+
+    private function triggerUploadWorker() {
+        // Use a lock file to prevent multiple upload worker instances
+        $lockFile = '/tmp/backup-upload-worker.lock';
+
+        // Check if a worker is already running
+        if (file_exists($lockFile)) {
+            $pid = trim(file_get_contents($lockFile));
+            // Check if the process is actually running
+            if ($pid && posix_kill($pid, 0)) {
+                // Worker is still running, don't start another
+                return;
+            } else {
+                // Stale lock file, remove it
+                unlink($lockFile);
+            }
+        }
+
+        // Trigger upload worker asynchronously
+        $scriptPath = dirname(__DIR__) . '/scripts/backup-upload-worker.php';
+        if (file_exists($scriptPath)) {
+            // Run in background without blocking the response
+            exec("php " . escapeshellarg($scriptPath) . " > /dev/null 2>&1 &");
+        }
+    }
     
     /**
      * Create a combined WordPress backup (site files + database)
